@@ -809,7 +809,7 @@ This model does not support to load several drivers. Loading several drivers is
     'name' => 'LCDd',
     'read_config' => [
       {
-        'backend' => 'ini_file',
+        'backend' => 'IniFile',
         'config_dir' => '/etc',
         'file' => 'LCDd.conf'
       }
